@@ -58,7 +58,8 @@ GtkWidget* search_box_new (AnjutaDocman* docman);
 void search_box_fill_search_focus (SearchBox* search_box, gboolean on_replace);
 void search_box_grab_line_focus (SearchBox* search_box);
 void search_box_set_replace (SearchBox* object, gboolean replace);
-gboolean search_box_incremental_search (SearchBox* search_box, gboolean search_forward);
+gboolean search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
+                                        gboolean wrap);
 
 void search_box_clear_highlight (SearchBox * search_box);
 void search_box_toggle_highlight (SearchBox * search_box, gboolean status);
