@@ -48,7 +48,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-#define PROJECT_WIZARD_DIRECTORY PACKAGE_DATA_DIR"/project"
+#define PROJECT_WIZARD_DIRECTORY PACKAGE_DATA_DIR "/project"
 
 /* Default property name useable in wizard file
  *---------------------------------------------------------------------------*/
@@ -60,7 +60,7 @@
 /* Widget and signal name found in glade file
  *---------------------------------------------------------------------------*/
 
-#define GTK_BUILDER_UI_FILE PACKAGE_DATA_DIR"/glade/anjuta-project-wizard.ui"
+#define GTK_BUILDER_UI_FILE PACKAGE_DATA_DIR "/glade/anjuta-project-wizard.ui"
 
 #define NEW_PROJECT_DIALOG "druid_window"
 #define PROJECT_LIST "project_list"
@@ -491,7 +491,7 @@ npw_druid_fill_property_page (NPWDruid* druid, NPWPage* page)
 	NPWDruidAddPropertyData data;
 
 	widget = gtk_assistant_get_nth_page (GTK_ASSISTANT (druid->window), druid->next_page);
-	
+
 	/* Remove previous widgets */
 	gtk_container_foreach (GTK_CONTAINER (npw_page_get_widget (page)), cb_druid_destroy_widget, NULL);
  		
@@ -715,7 +715,6 @@ npw_druid_save_valid_values (NPWDruid* druid)
 									"<b>%s</b>\n\n%s",
 									_("Invalid entry"),
 									data.error->str);
-		gtk_assistant_set_current_page (GTK_ASSISTANT (druid->window), ERROR_PAGE);
 		ok = FALSE;
 	}
 	else if (data.warning->len)
@@ -726,7 +725,6 @@ npw_druid_save_valid_values (NPWDruid* druid)
 									"<b>%s</b>\n\n%s",
 									_("Dubious entry"),
 									data.warning->str);
-		gtk_assistant_set_current_page (GTK_ASSISTANT (druid->window), ERROR_PAGE);
 		ok = FALSE;
 	}
 	
@@ -789,7 +787,7 @@ on_druid_get_new_page (NPWAutogen* gen, gpointer data)
 	NPWPage* page;
 
 	page = g_queue_peek_nth (druid->page_list, druid->next_page - PROPERTY_PAGE);
-
+	
 	if (npw_page_get_name (page) == NULL)
 	{
 		/* no page, display finish page */
@@ -916,15 +914,20 @@ check_and_warn_missing (NPWDruid *druid)
 		hbox = gtk_hbox_new (FALSE, 0);
 		gtk_widget_show (hbox);
 
+#ifdef ENABLE_PACKAGEKIT		
 		install_button =
 			gtk_button_new_with_label (_("Install missing packages"));
 		gtk_box_pack_end (GTK_BOX (hbox), install_button, FALSE, FALSE, 10);
 		g_signal_connect (install_button, "clicked",
 						  G_CALLBACK (on_install_button_clicked), druid);
 		gtk_widget_show (install_button);
+#endif
 
 		npw_druid_fill_error_page (druid, hbox,
 								   GTK_MESSAGE_WARNING,
+								   /* Translators: Application Manager is the program used to install
+								    * new application like apt on Ubuntu, yum on Fedora, zypper on
+								    * OpenSuSE and emerge on Gentoo */
 								  _("The missing programs are usually part of some distribution "
 									"packages and can be searched for in your Application Manager. "
 									"Similarly, the development packages are contained in special "
@@ -936,8 +939,6 @@ check_and_warn_missing (NPWDruid *druid)
 									_("Missing components"),
 									missing_message->str);
 		g_string_free (missing_message, TRUE);
-		
-		gtk_assistant_set_current_page (GTK_ASSISTANT (druid->window), ERROR_PAGE);
 	}
 	
 	return !missing_message;
@@ -955,6 +956,24 @@ on_druid_next (gint page, gpointer user_data)
 	return page == FINISH_PAGE ? -1 : PROGRESS_PAGE;
 }
 
+static gboolean
+on_druid_delayed_get_new_page (gpointer data)
+{
+	on_druid_get_new_page (NULL, data);
+
+	return FALSE;
+}
+
+static gboolean
+on_druid_delayed_set_error_page (gpointer data)
+{
+	GtkAssistant * assistant = (GtkAssistant *)data;
+	
+	gtk_assistant_set_current_page (assistant, ERROR_PAGE);
+	
+	return FALSE;
+}
+
 static void
 on_druid_prepare (GtkAssistant* assistant, GtkWidget *page, NPWDruid* druid)
 {
@@ -976,6 +995,11 @@ on_druid_prepare (GtkAssistant* assistant, GtkWidget *page, NPWDruid* druid)
 				/* Check if necessary programs for this project is installed */
 				if (!check_and_warn_missing (druid))
 				{   
+					/* The page change is delayed because in the latest version of
+					 * GtkAssistant, the page switch is not completely done when
+					 * the signal is called. A page change in the signal handler
+					 * will be partialy overwritten */
+					g_idle_add (on_druid_delayed_set_error_page, druid->window);
 					return;
 				}   
 				
@@ -991,7 +1015,11 @@ on_druid_prepare (GtkAssistant* assistant, GtkWidget *page, NPWDruid* druid)
 			if (!npw_druid_save_valid_values (druid))
 			{
 				/* Display error */
-				gtk_assistant_set_current_page (assistant, ERROR_PAGE);
+				/* The page change is delayed because in the latest version of
+				 * GtkAssistant, the page switch is not completely done when
+				 * the signal is called. A page change in the signal handler
+				 * will be partialy overwritten */
+				g_idle_add (on_druid_delayed_set_error_page, druid->window);
 				
 				return;
 			}
@@ -1011,8 +1039,12 @@ on_druid_prepare (GtkAssistant* assistant, GtkWidget *page, NPWDruid* druid)
 		}
 		else
 		{
-			/* Page is already in cache */
-			on_druid_get_new_page (NULL, (gpointer)druid);
+			/* Page is already in cache, change the page to display it */
+			/* The page change is delayed because in the latest version of
+			 * GtkAssistant, the page switch is not completely done when
+			 * the signal is called. A page change in the signal handler
+			 * will be partialy overwritten */
+			g_idle_add (on_druid_delayed_get_new_page, druid);
 		}
 	}
 	else if (current_page == ERROR_PAGE)
@@ -1053,6 +1085,7 @@ npw_druid_create_assistant (NPWDruid* druid, const gchar *directory)
 {
 	AnjutaShell *shell;
 	GtkBuilder *builder;
+	GError* error = NULL;		
 	GtkAssistant *assistant;
 	GtkWidget *page;
 	
@@ -1062,10 +1095,10 @@ npw_druid_create_assistant (NPWDruid* druid, const gchar *directory)
 
 	/* Create GtkAssistant using GtkBuilder, glade doesn't seem to work*/
 	builder = gtk_builder_new ();
-	if (!gtk_builder_add_from_file (builder, GTK_BUILDER_UI_FILE, NULL))
+	if (!gtk_builder_add_from_file (builder, GTK_BUILDER_UI_FILE, &error))
 	{
-		anjuta_util_dialog_error (GTK_WINDOW (shell),
-								  _("Unable to build project assistant user interface reading %s."), GTK_BUILDER_UI_FILE);
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
 		return NULL;
 	}
 	assistant = GTK_ASSISTANT (gtk_builder_get_object (builder, NEW_PROJECT_DIALOG));
